RefreshTokenAuth

Struct RefreshTokenAuth 

pub struct RefreshTokenAuth { /* private fields */ }
Refresh-token-grant auth session.

Construct via RefreshTokenAuth::builder.

Implementations

Source

impl RefreshTokenAuth

pub fn builder() -> RefreshTokenAuthBuilder

Begins constructing a RefreshTokenAuth.

Refresh-token grant (RFC 6749 6): once an access token is obtained through any flow that issues a refresh token (typically Web Server with PKCE), use that refresh token to mint new access tokens at will. The refresh token itself is long-lived.

Example
use cirrus::auth::RefreshTokenAuth;
use cirrus::Cirrus;
use std::sync::Arc;

let auth = RefreshTokenAuth::builder()
    .consumer_key("3MVG9...")
    .refresh_token("5Aep861...")
    .login_url("https://login.salesforce.com")
    .instance_url("https://my-org.my.salesforce.com")
    .build()?;
let sf = Cirrus::builder().auth(Arc::new(auth)).build()?;